@@ -94,6 +94,8 @@ class expect(object):
     # matchers. That is: short, active, prepended with a conjugation of be
     # Sensible alternative names are encouraged after the method definition to allow the matchers
     # To be used sensibly in a sentence like matter for those who want it
+    # REFACT: consider switching to the short form as the default and prefer to get the combinations from the 
+    # arbitrary chaining support?
     
     # On debugging matchers: Some pyton debuggers will hide all the internals of the expect method
     # To match py.tests behaviour. Read up on hidden frames and how to unhide them in your python debugger
@@ -113,6 +115,11 @@ class expect(object):
     
     false = is_false
     
+    def is_none(self):
+        self._assert(self._expected is None, "to be None")
+    
+    none = is_none
+    
     # REFACT: consider adding 'from' alias to allow syntax like expect(False).from(some_longish_expression())
     # Could enhance readability, not sure it's a good idea?
     def is_equal(self, something):
@@ -554,8 +561,12 @@ class ExpectTest(TestCase):
         expect(lambda: expect(1).not_to.be(1)) \
             .to_raise(AssertionError, r"Expect 1 not to be 1")
     
-    def _test_does_exist(self):
-        pass # Not quite sure it's needed. Aliasses: exists, is_not_none(?)
+    def test_is_none(self):
+        expect(None).is_none()
+        expect(0).is_not.none()
+        expect(False).is_not.none()
+        expect(lambda: expect(3).is_.none()).to_raise(AssertionError, r"Expect 3 to be None")
+    
     def test_is_included_in(self):
         expect(1).is_included_in(1,2,3)
         expect(1).is_included_in([1,2,3])
